@@ -1035,6 +1035,9 @@ def run_transform(run_options, **kwargs):
                 **kwargs)
 
 def run_transforms(transforms):
+    if (len(transforms) == 1):
+        return run_transform(transforms[0]['run_options'], **transforms[0]['kwargs'])
+
     run = start_run()
     parent_run_id = run.info.run_id
     print('parent_run_id = ' + str(parent_run_id))
